@@ -4,16 +4,19 @@ use crate::script_type::{ScriptType, ScriptTypeConfig};
 use crate::state::State;
 use crate::tag::{TagFilter, TagFilterGroup};
 use crate::util;
+use crate::{impl_de_by_from_str, impl_ser_by_to_string};
 use colored::Color;
 use fxhash::FxHashMap as HashMap;
 use handlebars::Handlebars;
 use serde::{Deserialize, Serialize};
 use std::path::{Path, PathBuf};
+use std::str::FromStr;
 use std::time::SystemTime;
 
 const CONFIG_FILE: &str = ".config.toml";
 
 static CONFIG: State<Config> = State::new();
+static PROMPT_LEVEL: State<PromptLevel> = State::new();
 
 fn de_nonempty_vec<'de, D, T>(deserializer: D) -> std::result::Result<Vec<T>, D::Error>
 where
@@ -56,30 +59,39 @@ impl From<Vec<String>> for Alias {
     }
 }
 
-#[derive(Deserialize, Serialize, PartialEq, Eq, Debug, Clone, Copy)]
+#[derive(Display, PartialEq, Eq, Debug, Clone, Copy)]
 pub enum PromptLevel {
+    #[display(fmt = "always")]
     Always,
+    #[display(fmt = "never")]
     Never,
+    #[display(fmt = "smart")]
     Smart,
+    #[display(fmt = "on_multi_fuzz")]
+    OnMultiFuzz,
 }
-impl PromptLevel {
-    pub fn always(self) -> bool {
-        self == PromptLevel::Always
-    }
-    pub fn never(self) -> bool {
-        self == PromptLevel::Never
-    }
-    pub fn smart(self) -> bool {
-        self == PromptLevel::Smart
+impl FromStr for PromptLevel {
+    type Err = Error;
+    fn from_str(s: &str) -> Result<Self> {
+        let l = match s {
+            "always" => PromptLevel::Always,
+            "never" => PromptLevel::Never,
+            "smart" => PromptLevel::Smart,
+            "on-multi-fuzz" => PromptLevel::OnMultiFuzz,
+            _ => return Err(Error::Format(FormatCode::PromptLevel, s.to_owned())),
+        };
+        Ok(l)
     }
 }
+impl_ser_by_to_string!(PromptLevel);
+impl_de_by_from_str!(PromptLevel);
 
 #[derive(Deserialize, Serialize, PartialEq, Eq, Debug, Clone)]
 pub struct Config {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub recent: Option<u32>,
     pub main_tag_filter: TagFilter,
-    pub prompt_level: PromptLevel,
+    prompt_level: PromptLevel,
     #[serde(deserialize_with = "de_nonempty_vec")]
     pub editor: Vec<String>,
     pub tag_filters: Vec<NamedTagFilter>,
@@ -103,6 +115,7 @@ impl Default for Config {
         }
         Config {
             last_modified: None,
+            recent: Some(999999), // NOTE: 顯示兩千多年份的資料！
             editor: vec!["vim".to_string()],
             prompt_level: PromptLevel::Smart,
             tag_filters: vec![
@@ -124,8 +137,7 @@ impl Default for Config {
             ],
             main_tag_filter: "+all".parse().unwrap(),
             categories: ScriptTypeConfig::default_script_types(),
-            alias: vec![
-                // FIXME: 一旦陣列實作了 intoiterator 就用陣列
+            alias: std::array::IntoIter::new([
                 gen_alias("la", &["ls", "-a"]),
                 gen_alias("ll", &["ls", "-l"]),
                 gen_alias("l", &["ls", "--grouping", "none"]),
@@ -133,15 +145,12 @@ impl Default for Config {
                 gen_alias("gc", &["rm", "--timeless", "--purge", "-f", "removed", "*"]),
                 gen_alias("tree", &["ls", "--grouping", "tree"]),
                 gen_alias("t", &["tags"]),
-                gen_alias("p", &["run", "-p"]),
+                gen_alias("p", &["run", "--previous-args"]),
                 gen_alias("pc", &["=util/historian!", "c", "--"]),
                 gen_alias("h", &["=util/historian!"]),
-            ]
-            .into_iter()
+            ])
             .collect(),
-            recent: Some(999999), // NOTE: 顯示兩千多年份的資料！
-            // FIXME: 一旦陣列實作了 intoiterator 就用陣列
-            env: vec![
+            env: std::array::IntoIter::new([
                 ("NAME", "{{name}}"),
                 ("HS_HOME", "{{hs_home}}"),
                 ("HS_CMD", "{{hs_cmd}}"),
@@ -156,8 +165,7 @@ impl Default for Config {
                 ),
                 ("HS_EXE", "{{hs_exe}}"),
                 ("HS_SOURCE", "{{hs_home}}/.hs_source"),
-            ]
-            .into_iter()
+            ])
             .map(|(k, v)| (k.to_owned(), v.to_owned()))
             .collect(),
         }
@@ -217,6 +225,16 @@ impl Config {
         CONFIG.set(Config::load(path::get_home())?);
         Ok(())
     }
+
+    pub fn set_prompt_level(l: Option<PromptLevel>) {
+        let c = Config::get();
+        let l = l.unwrap_or(c.prompt_level); // TODO: 測試由設定檔設定 prompt-level 的情境？
+        PROMPT_LEVEL.set(l);
+    }
+    pub fn get_prompt_level() -> PromptLevel {
+        *PROMPT_LEVEL.get()
+    }
+
     #[cfg(not(test))]
     pub fn get() -> &'static Config {
         CONFIG.get()
