@@ -1,9 +1,9 @@
 use crate::error::{
-    Contextable, Error, FormatCode::FilterQuery as FilterQueryCode, FormatCode::Regex as RegexCode,
-    FormatCode::ScriptQuery as ScriptQueryCode, Result,
+    Contextable, Error, FormatCode::Regex as RegexCode, FormatCode::ScriptQuery as ScriptQueryCode,
+    Result,
 };
+use crate::impl_ser_by_to_string;
 use crate::script::{IntoScriptName, ScriptName};
-use crate::tag::TagFilter;
 use regex::Regex;
 use serde::Serialize;
 use std::str::FromStr;
@@ -89,15 +89,7 @@ impl std::fmt::Display for ScriptQuery {
         Ok(())
     }
 }
-impl Serialize for ScriptQuery {
-    fn serialize<S: serde::Serializer>(
-        &self,
-        serializer: S,
-    ) -> std::result::Result<S::Ok, S::Error> {
-        let s = self.to_string();
-        serializer.serialize_str(&s)
-    }
-}
+impl_ser_by_to_string!(ScriptQuery);
 
 #[derive(Debug, Clone, Eq, PartialEq)]
 enum ScriptQueryInner {
@@ -159,40 +151,9 @@ impl FromStr for ScriptQuery {
         } else if s.starts_with('^') {
             ScriptQueryInner::Prev(parse_prev(s)?)
         } else {
-            ScriptName::valid(s).context("模糊搜尋仍需符合腳本名格式！")?; // NOTE: 單純檢查用
+            ScriptName::valid(s, true).context("模糊搜尋仍需符合腳本名格式！")?; // NOTE: 單純檢查用
             ScriptQueryInner::Fuzz(s.to_owned())
         };
         Ok(ScriptQuery { inner, bang })
     }
 }
-
-#[derive(Debug, Serialize)]
-pub struct FilterQuery {
-    pub name: Option<String>,
-    pub content: TagFilter,
-}
-
-impl FromStr for FilterQuery {
-    type Err = Error;
-    fn from_str(s: &str) -> Result<Self> {
-        let arr: Vec<&str> = s.split('=').collect();
-        match AsRef::<[&str]>::as_ref(&arr) {
-            [s] => {
-                log::trace!("解析無名篩選器：{}", s);
-                Ok(FilterQuery {
-                    name: None,
-                    content: s.parse()?,
-                })
-            }
-            [name, s] => {
-                log::trace!("解析有名篩選器：{} = {}", name, s);
-                Ok(FilterQuery {
-                    // TODO: 檢查名字
-                    name: Some(name.to_string()),
-                    content: s.parse()?,
-                })
-            }
-            _ => Err(Error::Format(FilterQueryCode, s.to_owned())),
-        }
-    }
-}
